@@ -26,7 +26,7 @@ struct _GameObject {
 void init_game (void);
 void quit_game (void);
 void game_keypress (gint);
-gint show_scores (gint, gboolean);
+void show_scores (void);
 void start_new_game (void);
 gboolean mouse_cb (GtkWidget * widget, GdkEventButton * e, gpointer data);
 gboolean move_cb (GtkWidget * widget, GdkEventMotion * e, gpointer data);
