@@ -4,7 +4,7 @@
    
    This library is free software; you can redistribute it and'or modify
    it under the terms of the GNU Library General Public License as published 
-   by the Free Software Foundation; either version 2, or (at your option)
+   by the Free Software Foundation; either version 3, or (at your option)
    any later version.
    
    This library is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
    GNU Library General Public License for more details.
 
    You should have received a copy of the GNU Library General Public License
-   along with this library; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with this library; if not, see <http://www.gnu.org/licenses/>.  */
 
 /* Authors:   Richard Hoelscher <rah@rahga.com> */
 
